.. @+leo-ver=5-thin
.. @+node:peckj.20130503092808.1680: * @file index.rst
.. @@language rest
.. Leo documentation master file, created by
   sphinx-quickstart on Fri May  3 09:15:27 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Leo's API documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 4

   leo


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. @-leo
